#

##

##

###

###

###

##

##

    	keys

    	tags
    		# vibes
    		# openers
    		# ships

    	summary
    		build

    		sign

    		verify

    	objectives ranked

    		[ ] allow for multiple key types

    			{
    				"address": "EEC_448_2:3043300506032b6571033a00e26960a83c45c0bb86e356cd727473e96682e76c6dd01c991a6ea0a394ecca27b467554d73e2a22b05425c1926a7a92befda5c1937d6876f00",
    			}

    	possibilities

    		[ ] voting key & proposal key

    			proposal key would be for proposing new moves
    			like sending coins.

    			However, could just have a voting account
    			and another account.

    				legend:
    					proposal
    						# treasure